@@ -9,7 +9,7 @@
 'use strict'
 var express = require('express'),
     router = express.Router(),
-    inspect = require('@open-cluster-management/security-middleware')
+    inspect = require('@stolostron/security-middleware')
 
 //controllers
 var app = require('./app'),
