@@ -1,14 +1,22 @@
-// /*******************************************************************************
-//  * Licensed Materials - Property of IBM
-//  * (c) Copyright IBM Corporation 2019. All Rights Reserved.
-//  *
-//  * Note to U.S. Government Users Restricted Rights:
-//  * Use, duplication or disclosure restricted by GSA ADP Schedule
-//  * Contract with IBM Corp.
-//  * Copyright (c) 2020 Red Hat, Inc.
-//  *******************************************************************************/
+/** *****************************************************************************
+ * Licensed Materials - Property of IBM
+ * (c) Copyright IBM Corporation 2019. All Rights Reserved.
+ *
+ * Note to U.S. Government Users Restricted Rights:
+ * Use, duplication or disclosure restricted by GSA ADP Schedule
+ * Contract with IBM Corp.
+ ****************************************************************************** */
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 import apolloClient from '../../lib/client/apollo-client'
+import { RESOURCE_TYPES } from '../../lib/shared/constants'
+import {
+  mutateResource,
+  mutateResourceSuccess,
+  mutateResourceFailure,
+  clearSuccessFinished
+} from './common'
 import {
   APPLICATION_CREATE_CLEAR_STATUS,
   APPLICATION_CREATE_IN_PROGRESS,
@@ -69,3 +77,22 @@ export const updateApplication = resourceJson => {
     })
   }
 }
+
+export const syncApplication = resourceJson => {
+  const resourceType = RESOURCE_TYPES.QUERY_APPLICATIONS
+  return dispatch => {
+    clearSuccessFinished(dispatch)
+    dispatch(mutateResource(resourceType))
+    return apolloClient.updateApplication(resourceJson).then(result => {
+      const errors =
+        _.get(result, 'data.updateApplication.errors') ||
+        _.get(result, 'errors')
+      if (errors && errors.length > 0) {
+        dispatch(mutateResourceFailure(resourceType, errors))
+      } else {
+        dispatch(mutateResourceSuccess(resourceType))
+      }
+      return result
+    })
+  }
+}
