@@ -1,12 +1,14 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2019. All Rights Reserved.
  *
  * Note to U.S. Government Users Restricted Rights:
  * Use, duplication or disclosure restricted by GSA ADP Schedule
  * Contract with IBM Corp.
- * Copyright (c) 2020 Red Hat, Inc.
+
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 'use strict'
 
 import _ from 'lodash'
@@ -29,6 +31,12 @@ const keepKeys = [
   'apps.open-cluster-management.io/git-branch',
   'apps.open-cluster-management.io/git-path',
   'apps.open-cluster-management.io/reconcile-option',
+  'apps.open-cluster-management.io/git-desired-commit',
+  'apps.open-cluster-management.io/git-tag',
+  'apps.open-cluster-management.io/git-clone-depth',
+  'apps.open-cluster-management.io/reconcile-rate',
+  'apps.open-cluster-management.io/manual-refresh-time',
+  'apps.open-cluster-management.io/bucket-path',
   'apps.open-cluster-management.io/deployables' //needed by the topology to show deployable information
 ]
 
