@@ -427,9 +427,9 @@ class ClusterDetailsContainer extends React.Component {
     const clusterJoined = clusterData.ManagedClusterJoined
     const clusterAvailable = clusterData.ManagedClusterConditionAvailable
 
-    if (clusterAccepted == false) {
+    if (clusterAccepted === false) {
       status = 'notaccepted'
-    } else if (clusterJoined == false) {
+    } else if (clusterJoined === false) {
       status = 'pendingimport'
     } else {
       status =
