@@ -1,31 +1,26 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2017, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 'use strict'
 
 import _ from 'lodash'
 import React from 'react'
 import PropTypes from 'prop-types'
-import loadable from 'loadable-components'
+import loadable from '@loadable/component'
 import { GET_ACTION_MODAL_STATE } from '../../apollo-client/queries/StateQueries'
 import { Query } from 'react-apollo'
-import { RESOURCE_TYPES } from '../../../lib/shared/constants'
 
 let RemoveResourceModal
+let SyncResourceModal
 
 class ActionModalApollo extends React.PureComponent {
   getMatchedModal = ({ type, resourceType, open, data }) => {
-    // remove the typename field
-    if (resourceType.name === RESOURCE_TYPES.QUERY_APPLICATIONS.name) {
-      resourceType = RESOURCE_TYPES.HCM_APPLICATIONS //use hcm app to edit, delete selection
-    }
-    resourceType = { name: resourceType.name, list: resourceType.list }
-
     switch (type) {
     case 'table.actions.applications.remove':
     case 'table.actions.subscriptions.remove':
@@ -39,7 +34,7 @@ class ActionModalApollo extends React.PureComponent {
             type: 'resource-remove',
             resourceType,
             label: {
-              primaryBtn: `modal.remove-${resourceType.name.toLowerCase()}.heading`,
+              primaryBtn: 'modal.remove.submit',
               label: `modal.remove-${resourceType.name.toLowerCase()}.label`,
               heading: `modal.remove-${resourceType.name.toLowerCase()}.heading`
             },
@@ -48,6 +43,23 @@ class ActionModalApollo extends React.PureComponent {
       )
     }
 
+    case 'actions.sync.application': {
+      return (
+        open &&
+          this.getSyncResourceModal({
+            open: true,
+            type: 'resource-sync',
+            resourceType,
+            label: {
+              primaryBtn: 'modal.sync.submit',
+              label: `modal.sync-${resourceType.name.toLowerCase()}.label`,
+              heading: `modal.sync-${resourceType.name.toLowerCase()}.heading`
+            },
+            data: data
+          })
+      )
+    }
+
     default:
       return null
     }
@@ -63,6 +75,16 @@ class ActionModalApollo extends React.PureComponent {
     return this.getModal(RemoveResourceModal, props)
   };
 
+  getSyncResourceModal = props => {
+    SyncResourceModal =
+      SyncResourceModal === undefined
+        ? loadable(() =>
+            import(/* webpackChunkName: "sync-resource-modal" */ '../modals/SyncResourceModal')
+        )
+        : SyncResourceModal
+    return this.getModal(SyncResourceModal, props)
+  };
+
   getModal = (Component, props) => <Component {...props} />;
 
   render() {
