@@ -1,11 +1,12 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2018, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 import React from 'react'
 import { withRouter } from 'react-router-dom'
 import PropTypes from 'prop-types'
@@ -17,7 +18,6 @@ import {
   getSingleResourceItem,
   resourceItemByName
 } from '../../../reducers/common'
-import { loadingComponent } from './utils'
 import { withLocale } from '../../../providers/LocaleProvider'
 import resources from '../../../../lib/shared/resources'
 import OverviewCards from '../OverviewCards'
@@ -28,22 +28,19 @@ resources(() => {
 })
 
 const ResourceOverview = withLocale(
-  ({ params, actions, showExpandedTopology, loading }) => {
+  ({ params, actions, showExpandedTopology, handleErrorMsg }) => {
     const serverProps = {}
     return (
       <div id="resource-overview" className="overview-content">
         <HeaderActions />
         <React.Fragment>
           <div className="overview-content-bottom overview-content-with-padding">
-            {loading ? (
-              loadingComponent()
-            ) : (
-              <OverviewCards
-                selectedAppName={params.name}
-                selectedAppNS={params.namespace}
-                serverProps={serverProps}
-              />
-            )}
+            <OverviewCards
+              selectedAppName={params.name}
+              selectedAppNS={params.namespace}
+              serverProps={serverProps}
+              handleErrorMsg={handleErrorMsg}
+            />
           </div>
 
           <div className="overview-content-bottom overview-content-with-padding">
@@ -51,6 +48,7 @@ const ResourceOverview = withLocale(
               showExpandedTopology={showExpandedTopology}
               params={params}
               actions={actions}
+              handleErrorMsg={handleErrorMsg}
             />
           </div>
         </React.Fragment>
