@@ -1,11 +1,12 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2018, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 import React from 'react'
 import R from 'ramda'
 import {
@@ -16,6 +17,10 @@ import {
   getEditLink,
   getSearchLink
 } from '../../lib/client/resource-helper'
+import {
+  isSearchAvailable,
+  isYAMLEditAvailable
+} from '../../lib/client/search-helper'
 import { cellWidth } from '@patternfly/react-table'
 import msgs from '../../nls/platform.properties'
 
@@ -45,20 +50,23 @@ export default {
       resourceKey: 'channel',
       transformFunction: createChannelLink,
       tooltipKey: 'table.header.subscriptions.channel.tooltip',
-      transforms: [cellWidth(20)]
+      transforms: [cellWidth(20)],
+      disabled: () => !isSearchAvailable()
     },
     {
       msgKey: 'table.header.applications',
       resourceKey: 'appCount',
       transformFunction: createApplicationsLink,
-      tooltipKey: 'table.header.subscriptions.applications.tooltip'
+      tooltipKey: 'table.header.subscriptions.applications.tooltip',
+      disabled: () => !isSearchAvailable()
     },
     {
       msgKey: 'table.header.clusters',
       tooltipKey: 'table.header.subscriptions.clusters.tooltip',
       resourceKey: 'clusterCount',
       transformFunction: createClustersLink,
-      textFunction: createClustersText
+      textFunction: createClustersText,
+      disabled: () => !isSearchAvailable()
     },
     {
       msgKey: 'table.header.timeWindow',
@@ -72,14 +80,21 @@ export default {
       transformFunction: getAge
     }
   ],
-  tableActions: [
-    {
+  tableActionsResolver: tableActionsResolver
+}
+
+function tableActionsResolver() {
+  const actions = []
+  if (isYAMLEditAvailable()) {
+    actions.push({
       key: 'table.actions.subscriptions.edit',
       link: {
         url: getEditLink
       }
-    },
-    {
+    })
+  }
+  if (isSearchAvailable()) {
+    actions.push({
       key: 'table.actions.subscriptions.search',
       link: {
         url: item =>
@@ -92,13 +107,14 @@ export default {
             }
           })
       }
-    },
-    {
-      key: 'table.actions.subscriptions.remove',
-      modal: true,
-      delete: true
-    }
-  ]
+    })
+  }
+  actions.push({
+    key: 'table.actions.subscriptions.remove',
+    modal: true,
+    delete: true
+  })
+  return actions
 }
 
 function createChannelLink(item) {
