@@ -1,12 +1,13 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2017, 2020. All Rights Reserved.
  *
  * Note to U.S. Government Users Restricted Rights:
  * Use, duplication or disclosure restricted by GSA ADP Schedule
  * Contract with IBM Corp.
- * Copyright (c) 2020 Red Hat, Inc.
- *******************************************************************************/
+ ****************************************************************************** */
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 /// <reference types="cypress" />
 // ***********************************************************
@@ -26,12 +27,15 @@
  * @type {Cypress.PluginConfig}
  */
 
+const _ = require("lodash");
 const fs = require("fs");
 const yaml = require("js-yaml");
 const dir = "./cypress/test-artifacts/";
-const testConfig = require("../config").getConfig();
+const testConfig = require("../config").getConfig().config;
+const secretConfig = require("../config").getConfig().secretConfig;
 const kubeConfig = require("../config").getKubeConfig();
 const getUsers = require("../config").getUsers();
+const rbacConfig = require("../config").getrbacConfig();
 
 module.exports = (on, config) => {
   // `on` is used to hook into various events Cypress emits
@@ -41,6 +45,14 @@ module.exports = (on, config) => {
   // config.env.TEST_CONFIG = testConfig
   require("cypress-log-to-output").install(on);
 
+  on("task", {
+    log(message) {
+      console.log(message);
+
+      return null;
+    }
+  });
+
   on("task", {
     yaml2json(filename) {
       obj = yaml.safeLoadAll(fs.readFileSync(dir + filename, "utf-8"));
@@ -85,21 +97,34 @@ module.exports = (on, config) => {
     }
   });
 
-
-  on("task",{
-    readFileMaybe (filename) {
+  on("task", {
+    readFileMaybe(filename) {
       if (fs.existsSync(filename)) {
-        return fs.readFileSync(filename, 'utf8')
+        return fs.readFileSync(filename, "utf8");
       }
-      return false
+      return false;
     }
   });
 
   if (config.env.TEST_MODE === "functional") config.videoUploadOnPasses = false; // disable video compression for passing spec files
 
-  config.env.TEST_CONFIG = testConfig;
+  config.env.TEST_CONFIG = JSON.parse(testConfig);
+  config.env.TEST_CONFIG_EXCLUDE_ARGO = _.pickBy(
+    JSON.parse(testConfig),
+    function(value, key) {
+      return !_.startsWith(key, "argo");
+    }
+  );
+  config.env.SECRET_CONFIG = JSON.parse(secretConfig);
   config.env.KUBE_CONFIG = kubeConfig;
   config.env.USER_CONFIG = getUsers;
+  config.env.RBAC_CONFIG = JSON.parse(rbacConfig);
+
+  config.env.IS_CANARY = !(
+    config.baseUrl.includes("localhost") || config.env.PROW
+  )
+    ? "true"
+    : "";
 
   return config;
 };
