@@ -5,7 +5,7 @@ const config = Cypress.env("TEST_CONFIG_EXCLUDE_ARGO");
 import { testGitApiInput } from "../../views/common";
 
 describe("Application UI: [P3][Sev3][app-lifecycle-ui] Application Creation Validate git api Test", () => {
-  if (!Cypress.env("IS_CANARY") && Cypress.env("TEST_MODE") !== "smoke") {
+  if (!Cypress.env("IS_CANARY") && Cypress.env("TEST_MODE") !== "BVT") {
     //run this test only on PRs
     it(`Verify git api can access git branches`, () => {
       cy.log("Test cluster", Cypress.config().baseUrl);
@@ -19,7 +19,7 @@ describe("Application UI: [P3][Sev3][app-lifecycle-ui] Application Creation Vali
       }
     });
   } else {
-    it("Skipping test for canary or smoke test mode", () => {
+    it("Skipping test for canary or BVT test mode", () => {
       cy.log(
         "Test is run when running full suite for PRs or against localhost"
       );
