@@ -1,6 +1,5 @@
-/*******************************************************************************
- * Copyright (c) 2020 Red Hat, Inc.
- *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 "use strict";
 
 import {
@@ -917,6 +916,7 @@ describe("filterRelationshipNodes", () => {
         type: "deployment",
         namespace: "default",
         specs: {
+          clustersNames: ["braveman"],
           isDesign: false,
           pulse: "green",
           parent: {
@@ -930,6 +930,7 @@ describe("filterRelationshipNodes", () => {
         type: "replicaset",
         namespace: "default",
         specs: {
+          clustersNames: ["braveman"],
           isDesign: false,
           pulse: "green",
           parent: {
@@ -970,6 +971,7 @@ describe("filterRelationshipNodes", () => {
         "member--deployable--member--deployable--member--clusters--braveman--open-cluster-management--guestbook-app-guestbook-frontend-deployment--frontend",
       namespace: "default",
       specs: {
+        clustersNames: ["braveman"],
         isDesign: false,
         parent: {
           parentId: "member-cluster"
@@ -983,6 +985,7 @@ describe("filterRelationshipNodes", () => {
         "member--replicaset--member--deployable--member--clusters--braveman--open-cluster-management--guestbook-app-guestbook-frontend-deployment--frontend",
       namespace: "default",
       specs: {
+        clustersNames: ["braveman"],
         isDesign: false,
         parent: {
           name: "deployment1",
@@ -995,7 +998,7 @@ describe("filterRelationshipNodes", () => {
       type: "replicaset"
     }
   ];
-  it("filter node", () => {
+  it("filter node by cluster name", () => {
     expect(
       filterRelationshipNodes(
         mockDataRelationshipNodes.nodes,
