@@ -1,7 +1,8 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2019. All Rights Reserved.
  *  Copyright (c) 2020 Red Hat, Inc.
+ * Copyright Contributors to the Open Cluster Management project
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
@@ -108,6 +109,18 @@ jest.mock("../../../../../lib/client/apollo-client", () => ({
   }),
   search: jest.fn(resourceType => Promise.resolve({ response: resourceType }))
 }));
+
+jest.mock("../../../../../lib/client/access-helper.js", () => ({
+  canCreateActionAllNamespaces: jest.fn(() => {
+    const data = {
+      data: {
+        userAccessAnyNamespaces: true
+      }
+    };
+    return Promise.resolve(data);
+  })
+}));
+
 const React = require("../../../../../node_modules/react");
 
 import OverviewCards from "../../../../../src-web/components/common/OverviewCards";
@@ -115,6 +128,7 @@ import OverviewCards from "../../../../../src-web/components/common/OverviewCard
 import { mount } from "enzyme";
 import renderer from "react-test-renderer";
 import * as reducers from "../../../../../src-web/reducers";
+import { BrowserRouter } from "react-router-dom";
 
 import { createStore, combineReducers, applyMiddleware, compose } from "redux";
 import thunkMiddleware from "redux-thunk";
@@ -143,7 +157,23 @@ window.open = () => {}; // provide an empty implementation for window.open
 describe("OverviewCards", () => {
   it("OverviewCards makes apollo calls with success return", () => {
     renderer.create(
-      <MockedProvider mocks={[]} addTypename={false}>
+      <BrowserRouter>
+        <MockedProvider mocks={[]} addTypename={false}>
+          <Provider store={storeApp}>
+            <OverviewCards
+              selectedAppName="mortgage-app"
+              selectedAppNS="default"
+              serverProps={serverProps}
+            />
+          </Provider>
+        </MockedProvider>
+      </BrowserRouter>
+    );
+  });
+
+  it("has functioning onclick, one app", () => {
+    const wrapper = mount(
+      <BrowserRouter>
         <Provider store={storeApp}>
           <OverviewCards
             selectedAppName="mortgage-app"
@@ -151,41 +181,11 @@ describe("OverviewCards", () => {
             serverProps={serverProps}
           />
         </Provider>
-      </MockedProvider>
-    );
-  });
-
-  it("has functioning onclick, one app", () => {
-    const wrapper = mount(
-      <Provider store={storeApp}>
-        <OverviewCards
-          selectedAppName="mortgage-app"
-          selectedAppNS="default"
-          serverProps={serverProps}
-        />
-      </Provider>
+      </BrowserRouter>
     );
 
-    wrapper.find({ id: "app-search-link" }).simulate("click");
     wrapper
       .find({ id: "app-search-link" })
       .simulate("keypress", { key: "Enter" });
   });
-
-  it("OverviewCards successfully handles change in props to refetch", () => {
-    const wrapper = mount(
-      <Provider store={storeApp}>
-        <OverviewCards
-          selectedAppName="mortgage-app"
-          selectedAppNS="default"
-          serverProps={serverProps}
-        />
-      </Provider>
-    );
-
-    // change interval to 30000
-    wrapper.setState({ refetch: { doRefetch: false, interval: 30000 } });
-    // manual refetch data
-    wrapper.setState({ refetch: { doRefetch: true, interval: 30000 } });
-  });
 });
