@@ -1,12 +1,13 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2018, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * Note to U.S. Government Users Restricted Rights:
  * Use, duplication or disclosure restricted by GSA ADP Schedule
  * Contract with IBM Corp.
- *******************************************************************************/
+ ****************************************************************************** */
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 "use strict";
 
 jest.mock("../../../../lib/client/access-helper", () => ({
@@ -267,7 +268,7 @@ jest.mock("../../../../lib/client/apollo-client", () => ({
                     "helloworld-simple-ns_apps.open-cluster-management.io_subscriptions",
                   channel:
                     "ggithubcom-fxiang1-app-samples-ns/ggithubcom-fxiang1-app-samples",
-                  _gitbranch: "master",
+                  _gitbranch: "main",
                   localPlacement: "false",
                   _hubClusterResource: "true",
                   label: "app=helloworld-simple",
@@ -321,7 +322,7 @@ jest.mock("../../../../lib/client/apollo-client", () => ({
                       _hostingDeployable:
                         "local-cluster/helloworld-simple-subscription-1-deployable-kkgkh",
                       _hubClusterResource: "true",
-                      _gitbranch: "master",
+                      _gitbranch: "main",
                       _hostingSubscription:
                         "helloworld-simple-ns/helloworld-simple-subscription-1",
                       timeWindow: "none",
@@ -609,7 +610,7 @@ jest.mock("../../../../lib/client/apollo-client", () => ({
                         "helloworld-simple-ns_apps.open-cluster-management.io_subscriptions",
                       channel:
                         "ggithubcom-fxiang1-app-samples-ns/ggithubcom-fxiang1-app-samples",
-                      _gitbranch: "master",
+                      _gitbranch: "main",
                       localPlacement: "false",
                       _hubClusterResource: "true",
                       cluster: "local-cluster",
@@ -779,7 +780,10 @@ import { BrowserRouter } from "react-router-dom";
 describe("RemoveResourceModal test", () => {
   const handleModalClose = jest.fn();
   const handleModalSubmit = jest.fn();
-  const resourceType = { name: "HCMApplication", list: "HCMApplicationList" };
+  const resourceType = {
+    name: "QueryApplications",
+    list: "QueryApplicationList"
+  };
   const preloadedState = window.__PRELOADED_STATE__;
   const composeEnhancers =
     window.__REDUX_DEVTOOLS_EXTENSION_COMPOSE__ || compose;
@@ -839,7 +843,7 @@ describe("RemoveResourceModal test", () => {
       .simulate("click");
 
     component
-      .find(".pf-m-secondary")
+      .find(".pf-m-link")
       .at(0)
       .simulate("click");
 
@@ -881,7 +885,7 @@ describe("RemoveResourceModal test", () => {
       .simulate("click");
 
     component
-      .find(".pf-m-secondary")
+      .find(".pf-m-link")
       .at(0)
       .simulate("click");
 
