@@ -1,11 +1,12 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2018, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 import {
   secondaryHeader,
@@ -17,6 +18,9 @@ import {
 
 import { QueryApplicationList } from "../components/TestingData";
 
+const dateNowStub = jest.fn(() => 1530518207007);
+global.Date.now = dateNowStub;
+
 describe("secondaryHeader creation", () => {
   it("should return a default state", () => {
     const action = {};
@@ -81,6 +85,7 @@ describe("resourceReducerFunction", () => {
     const expectedValue = {
       test: "test",
       status: "DONE",
+      responseTime: 1530518207007,
       items: [],
       resourceVersion: 0
     };
@@ -97,7 +102,8 @@ describe("resourceReducerFunction", () => {
     const expectedValue = {
       test: "test",
       status: "ERROR",
-      err: "error"
+      err: "error",
+      responseTime: 1530518207007
     };
     expect(resourceReducerFunction(state, action)).toEqual(expectedValue);
   });
@@ -358,24 +364,6 @@ describe("resourceReducerFunction", () => {
     };
     expect(resourceReducerFunction(state, action)).toEqual(expectedValue);
   });
-  it("should return a state for RESOURCE_MUTATE action", () => {
-    const state = {
-      pendingActions: {}
-    };
-    const action = {
-      type: "RESOURCE_MUTATE",
-      resourceName: "aaa",
-      item: {
-        name: "test"
-      }
-    };
-    const expectedValue = {
-      mutateErrorMsg: null,
-      mutateStatus: "IN_PROGRESS",
-      pendingActions: [{ action: "RESOURCE_MUTATE", name: "aaa" }]
-    };
-    expect(resourceReducerFunction(state, action)).toEqual(expectedValue);
-  });
 
   it("should return a state for RESOURCE_MUTATE_FAILURE action", () => {
     const state = {
