@@ -61,5 +61,5 @@ export CYPRESS_MANAGED_OCP_USER=$(echo $MANAGED_CREDS | jq -r '.username')
 export CYPRESS_MANAGED_OCP_PASS=$(echo $MANAGED_CREDS | jq -r '.password')
 export CYPRESS_PROW="true"
 
-echo `Running ${CYPRESS_TEST_MODE} tests`
+echo "Running ${CYPRESS_TEST_MODE} tests"
 ./start-cypress-tests.sh
\ No newline at end of file
