@@ -65,7 +65,7 @@ if [[ "$CLEAN_UP" == "true" ]]; then
   oc delete namespace ui-helm-ns
   oc delete namespace ui-helm2-ns
   oc delete namespace ui-obj-ns
-  oc delete operator awx-resource-operator.app-ui-ansibleoperator
+  oc delete operator ansible-automation-platform-operator.app-ui-ansibleoperator
 
   echo "Clean up done. Exiting."
   exit 0
