@@ -19,12 +19,12 @@ import React from "react";
 import PropTypes from "prop-types";
 import VictoryPortal from "../victory-portal/victory-portal";
 import Rect from "../victory-primitives/rect";
-import CustomPropTypes from "../victory-util/prop-types";
-import Helpers from "../victory-util/helpers";
-import LabelHelpers from "../victory-util/label-helpers";
-import Style from "../victory-util/style";
-import Log from "../victory-util/log";
-import TextSize from "../victory-util/textsize";
+import * as CustomPropTypes from "../victory-util/prop-types";
+import * as Helpers from "../victory-util/helpers";
+import * as LabelHelpers from "../victory-util/label-helpers";
+import * as Style from "../victory-util/style";
+import * as Log from "../victory-util/log";
+import * as TextSize from "../victory-util/textsize";
 import TSpan from "../victory-primitives/tspan";
 import Text from "../victory-primitives/text";
 var defaultStyles = {
