@@ -9,8 +9,8 @@ function maxFileSizeUnitTransform(maxLogSize) {
     G: 1024 * 1024 * 1024,
   };
   const validUnit = Object.keys(units);
-  const unit = maxLogSize.substr(maxLogSize.length - 1).toLocaleUpperCase();
-  const value = maxLogSize.substring(0, maxLogSize.length - 1).trim();
+  const unit = maxLogSize.slice(-1).toLocaleUpperCase();
+  const value = maxLogSize.slice(0, -1).trim();
 
   if (validUnit.indexOf(unit) < 0 || !Number.isInteger(Number(value))) {
     throw Error(`maxLogSize: "${maxLogSize}" is invalid`);
