@@ -11,7 +11,12 @@ let sprite;
 if (isSpriteExists) {
   sprite = window[spriteGlobalVarName];
 } else {
-  sprite = new BrowserSprite({ attrs: { id: spriteNodeId } });
+  sprite = new BrowserSprite({
+    attrs: {
+      id: spriteNodeId,
+      'aria-hidden': 'true'
+    }
+  });
   window[spriteGlobalVarName] = sprite;
 }
 
