@@ -9,27 +9,26 @@ var map = require('./map');
  * `chain` maps a function over a list and concatenates the results. `chain`
  * is also known as `flatMap` in some libraries
  *
- * Dispatches to the `chain` method of the second argument, if present,
- * according to the [FantasyLand Chain spec](https://github.com/fantasyland/fantasy-land#chain).
+ * Dispatches to the `chain` method of the second argument, if present.
  *
  * @func
  * @memberOf R
  * @since v0.3.0
  * @category List
- * @sig Chain m => (a -> m b) -> m a -> m b
- * @param {Function} fn The function to map with
- * @param {Array} list The list to map over
- * @return {Array} The result of flat-mapping `list` with `fn`
+ * @sig (a -> [b]) -> [a] -> [b]
+ * @param {Function} fn
+ * @param {Array} list
+ * @return {Array}
  * @example
  *
  *      var duplicate = n => [n, n];
  *      R.chain(duplicate, [1, 2, 3]); //=> [1, 1, 2, 2, 3, 3]
- *
- *      R.chain(R.append, R.head)([1, 2, 3]); //=> [1, 2, 3, 1]
  */
-module.exports = _curry2(_dispatchable(['chain'], _xchain, function chain(fn, monad) {
+module.exports = _curry2(_dispatchable('chain', _xchain, function chain(fn, monad) {
   if (typeof monad === 'function') {
-    return function(x) { return fn(monad(x))(x); };
+    return function() {
+      return monad.call(this, fn.apply(this, arguments)).apply(this, arguments);
+    };
   }
   return _makeFlat(false)(map(fn, monad));
 }));
