@@ -4,13 +4,17 @@ import badgeStyles from '@patternfly/react-styles/css/components/Badge/badge';
 import formStyles from '@patternfly/react-styles/css/components/FormControl/form-control';
 import buttonStyles from '@patternfly/react-styles/css/components/Button/button';
 import { css } from '@patternfly/react-styles';
-import TimesCircleIcon from '@patternfly/react-icons/dist/js/icons/times-circle-icon';
+import TimesCircleIcon from '@patternfly/react-icons/dist/esm/icons/times-circle-icon';
+import CheckCircleIcon from '@patternfly/react-icons/dist/esm/icons/check-circle-icon';
+import ExclamationTriangleIcon from '@patternfly/react-icons/dist/esm/icons/exclamation-triangle-icon';
+import ExclamationCircleIcon from '@patternfly/react-icons/dist/esm/icons/exclamation-circle-icon';
 import { SelectMenu } from './SelectMenu';
 import { SelectOption, SelectOptionObject } from './SelectOption';
 import { SelectGroup, SelectGroupProps } from './SelectGroup';
 import { SelectToggle } from './SelectToggle';
 import { SelectContext, SelectVariant, SelectDirection, KeyTypes } from './selectConstants';
 import { Chip, ChipGroup, ChipGroupProps } from '../ChipGroup';
+import { Spinner } from '../Spinner';
 import {
   keyHandler,
   getNextIndex,
@@ -22,11 +26,18 @@ import {
 } from '../../helpers';
 import { Divider } from '../Divider';
 import { ToggleMenuBaseProps, Popper } from '../../helpers/Popper/Popper';
-import { createRenderableFavorites, extendItemsWithFavorite } from './favorites';
+import { createRenderableFavorites, extendItemsWithFavorite } from '../../helpers/favorites';
+import { ValidatedOptions } from '../../helpers/constants';
 
 // seed for the aria-labelledby ID
 let currentId = 0;
 
+export interface SelectViewMoreObject {
+  /** View more text */
+  text: string;
+  /** Callback for when the view more button is clicked */
+  onClick: (event: React.MouseEvent | React.ChangeEvent) => void;
+}
 export interface SelectProps
   extends ToggleMenuBaseProps,
     Omit<React.HTMLProps<HTMLDivElement>, 'onSelect' | 'ref' | 'checked' | 'selected'>,
@@ -47,6 +58,14 @@ export interface SelectProps
   isDisabled?: boolean;
   /** Flag to indicate if the typeahead select allows new items */
   isCreatable?: boolean;
+  /** Value to indicate if the select is modified to show that validation state.
+   * If set to success, select will be modified to indicate valid state.
+   * If set to error, select will be modified to indicate error state.
+   * If set to warning, select will be modified to indicate warning state.
+   */
+  validated?: 'success' | 'warning' | 'error' | 'default';
+  /** @beta Loading variant to display either the spinner or the view more text button */
+  loadingVariant?: 'spinner' | SelectViewMoreObject;
   /** Text displayed in typeahead select to prompt the user to create an item */
   createText?: string;
   /** Title text of Select */
@@ -63,6 +82,10 @@ export interface SelectProps
   'aria-label'?: string;
   /** Id of label for the Select aria-labelledby */
   'aria-labelledby'?: string;
+  /** Id of div for the select aria-labelledby */
+  'aria-describedby'?: string;
+  /** Flag indicating if the select is an invalid state */
+  'aria-invalid'?: boolean;
   /** Label for input field of type ahead select variants */
   typeAheadAriaLabel?: string;
   /** Label for clear selection button of type ahead select variants */
@@ -88,9 +111,11 @@ export interface SelectProps
   /** Callback for typeahead clear button */
   onClear?: (event: React.MouseEvent) => void;
   /** Optional callback for custom filtering */
-  onFilter?: (e: React.ChangeEvent<HTMLInputElement>) => React.ReactElement[];
+  onFilter?: (e: React.ChangeEvent<HTMLInputElement> | null, value: string) => React.ReactElement[] | undefined;
   /** Optional callback for newly created options */
   onCreateOption?: (newOptionValue: string) => void;
+  /** Optional event handler called each time the value in the typeahead input changes. */
+  onTypeaheadInputChanged?: (value: string) => void;
   /** Variant of rendered Select */
   variant?: 'single' | 'checkbox' | 'typeahead' | 'typeaheadmulti';
   /** Width of the select container as a number of px or string percentage */
@@ -113,10 +138,14 @@ export interface SelectProps
   chipGroupProps?: Omit<ChipGroupProps, 'children' | 'ref'>;
   /** Optional props to render custom chip group in the typeaheadmulti variant */
   chipGroupComponent?: React.ReactNode;
+  /** @beta Flag for retaining keyboard-entered value in typeahead text field when focus leaves input away */
+  isInputValuePersisted?: boolean;
+  /** Content rendered in the footer of the select menu */
+  footer?: React.ReactNode;
 }
 
 export interface SelectState {
-  openedOnEnter: boolean;
+  focusFirstOption: boolean;
   typeaheadInputValue: string | null;
   typeaheadFilteredChildren: React.ReactNode[];
   favoritesGroup: React.ReactNode[];
@@ -125,6 +154,7 @@ export interface SelectState {
   tabbedIntoFavoritesMenu: boolean;
   typeaheadStoredIndex: number;
   ouiaStateId: string;
+  viewMoreNextIndex: number;
 }
 
 export class Select extends React.Component<SelectProps & OUIAProps, SelectState> {
@@ -136,6 +166,7 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
   private inputRef = React.createRef<HTMLInputElement>();
   private refCollection: HTMLElement[][] = [[]];
   private optionContainerRefCollection: HTMLElement[] = [];
+  private footerRef = React.createRef<HTMLDivElement>();
 
   static defaultProps: PickOptional<SelectProps> = {
     children: [] as React.ReactElement[],
@@ -147,8 +178,11 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
     isPlain: false,
     isDisabled: false,
     isCreatable: false,
+    validated: 'default',
     'aria-label': '',
     'aria-labelledby': '',
+    'aria-describedby': '',
+    'aria-invalid': false,
     typeAheadAriaLabel: '',
     clearSelectionsAriaLabel: 'Clear all',
     toggleAriaLabel: 'Options menu',
@@ -163,6 +197,7 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
     onCreateOption: () => undefined as void,
     toggleIcon: null as React.ReactElement,
     onFilter: null,
+    onTypeaheadInputChanged: null,
     customContent: null,
     hasInlineFilter: false,
     inlineFilterPlaceholderText: null,
@@ -172,11 +207,12 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
     favorites: [] as string[],
     favoritesLabel: 'Favorites',
     ouiaSafe: true,
-    chipGroupComponent: null
+    chipGroupComponent: null,
+    isInputValuePersisted: false
   };
 
   state: SelectState = {
-    openedOnEnter: false,
+    focusFirstOption: false,
     typeaheadInputValue: null,
     typeaheadFilteredChildren: React.Children.toArray(this.props.children),
     favoritesGroup: [] as React.ReactNode[],
@@ -184,7 +220,8 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
     typeaheadStoredIndex: -1,
     creatableValue: '',
     tabbedIntoFavoritesMenu: false,
-    ouiaStateId: getDefaultOUIAId(Select.displayName, this.props.variant)
+    ouiaStateId: getDefaultOUIAId(Select.displayName, this.props.variant),
+    viewMoreNextIndex: -1
   };
 
   getTypeaheadActiveChild = (typeaheadCurrIndex: number) =>
@@ -195,16 +232,40 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
       this.refCollection[0][0] = this.filterRef.current;
     }
 
-    if (!prevState.openedOnEnter && this.state.openedOnEnter && !this.props.customContent && this.refCollection[0]) {
-      this.refCollection[0][0].focus();
+    // Move focus to top of the menu if state.focusFirstOption was updated to true and the menu does not have custom content
+    if (!prevState.focusFirstOption && this.state.focusFirstOption && !this.props.customContent) {
+      const firstRef = this.refCollection.find(ref => ref !== null);
+      if (firstRef && firstRef[0]) {
+        firstRef[0].focus();
+      }
     }
 
-    if (prevProps.children !== this.props.children) {
-      this.setState({
-        typeaheadFilteredChildren: React.Children.toArray(this.props.children)
-      });
+    // if viewMoreNextIndex is not -1, view more was clicked, set focus on first newly loaded item
+    if (
+      this.state.viewMoreNextIndex !== -1 &&
+      this.refCollection.length > this.state.viewMoreNextIndex &&
+      this.props.loadingVariant !== 'spinner'
+    ) {
+      this.refCollection[this.state.viewMoreNextIndex][0].focus();
     }
 
+    // the number or contents of the children has changed, update state.typeaheadFilteredChildren
+    if (
+      prevProps.children.length !== this.props.children.length ||
+      prevProps.children.some((child: React.ReactElement, index: number) => {
+        if (child.props && this.props.children[index].props) {
+          return child.props.value !== this.props.children[index].props.value;
+        } else {
+          return child !== this.props.children[index];
+        }
+      })
+    ) {
+      this.updateTypeAheadFilteredChildren(prevState.typeaheadInputValue || '', null);
+    }
+
+    // for menus with favorites,
+    // if the number of favorites or typeahead filtered children has changed, the generated
+    // list of favorites needs to be updated
     if (
       this.props.onFavorite &&
       (this.props.favorites.length !== prevProps.favorites.length ||
@@ -232,12 +293,25 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
   };
 
   onEnter = () => {
-    this.setState({ openedOnEnter: true });
+    this.setState({ focusFirstOption: true });
+  };
+
+  onToggle = (isExpanded: boolean) => {
+    const { isInputValuePersisted, onSelect, onToggle, hasInlineFilter } = this.props;
+    if (!isExpanded && isInputValuePersisted && onSelect) {
+      onSelect(undefined, this.inputRef.current ? this.inputRef.current.value : '');
+    }
+    if (isExpanded && hasInlineFilter) {
+      this.setState({
+        focusFirstOption: true
+      });
+    }
+    onToggle(isExpanded);
   };
 
   onClose = () => {
     this.setState({
-      openedOnEnter: false,
+      focusFirstOption: false,
       typeaheadInputValue: null,
       typeaheadFilteredChildren: React.Children.toArray(this.props.children),
       typeaheadCurrIndex: -1,
@@ -246,28 +320,48 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
   };
 
   onChange = (e: React.ChangeEvent<HTMLInputElement>) => {
-    const { onFilter, isCreatable, onCreateOption, createText, noResultsFoundText, children, isGrouped } = this.props;
-    let typeaheadFilteredChildren: any;
-
     if (e.target.value.toString() !== '' && !this.props.isOpen) {
-      this.props.onToggle(true);
+      this.onToggle(true);
     }
 
+    if (this.props.onTypeaheadInputChanged) {
+      this.props.onTypeaheadInputChanged(e.target.value.toString());
+    }
+
+    this.setState({
+      typeaheadCurrIndex: -1,
+      typeaheadInputValue: e.target.value,
+      creatableValue: e.target.value
+    });
+    this.updateTypeAheadFilteredChildren(e.target.value.toString(), e);
+    this.refCollection = [[]];
+  };
+
+  updateTypeAheadFilteredChildren = (typeaheadInputValue: string, e: React.ChangeEvent<HTMLInputElement> | null) => {
+    let typeaheadFilteredChildren: any;
+
+    const { onFilter, isCreatable, onCreateOption, createText, noResultsFoundText, children, isGrouped } = this.props;
+
     if (onFilter) {
-      typeaheadFilteredChildren = onFilter(e) || children;
+      /* The updateTypeAheadFilteredChildren callback is not only called on input changes but also when the children change.
+       * In this case the e is null but we can get the typeaheadInputValue from the state.
+       */
+      typeaheadFilteredChildren = onFilter(e, e ? e.target.value : typeaheadInputValue) || children;
     } else {
       let input: RegExp;
       try {
-        input = new RegExp(e.target.value.toString(), 'i');
+        input = new RegExp(typeaheadInputValue.toString(), 'i');
       } catch (err) {
-        input = new RegExp(e.target.value.toString().replace(/[.*+?^${}()|[\]\\]/g, '\\$&'), 'i');
+        input = new RegExp(typeaheadInputValue.toString().replace(/[.*+?^${}()|[\]\\]/g, '\\$&'), 'i');
       }
       const childrenArray = React.Children.toArray(children) as React.ReactElement<SelectGroupProps>[];
       if (isGrouped) {
         const childFilter = (child: React.ReactElement<SelectGroupProps>) =>
-          child.props.value && this.getDisplay(child.props.value.toString(), 'text').search(input) === 0;
+          child.props.value &&
+          child.props.value.toString &&
+          this.getDisplay(child.props.value.toString(), 'text').search(input) === 0;
         typeaheadFilteredChildren =
-          e.target.value.toString() !== ''
+          typeaheadInputValue.toString() !== ''
             ? React.Children.map(children, group => {
                 if (group.type === SelectGroup) {
                   const filteredGroupChildren = (React.Children.toArray(group.props.children) as React.ReactElement<
@@ -286,8 +380,25 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
             : childrenArray;
       } else {
         typeaheadFilteredChildren =
-          e.target.value.toString() !== ''
-            ? childrenArray.filter(child => this.getDisplay(child.props.value.toString(), 'text').search(input) === 0)
+          typeaheadInputValue.toString() !== ''
+            ? childrenArray.filter(child => {
+                const valueToCheck = child.props.value;
+                // Dividers don't have value and should not be filtered
+                if (!valueToCheck) {
+                  return true;
+                }
+
+                const isSelectOptionObject =
+                  typeof valueToCheck !== 'string' &&
+                  (valueToCheck as SelectOptionObject).toString &&
+                  (valueToCheck as SelectOptionObject).compareTo;
+
+                if (isSelectOptionObject) {
+                  return (valueToCheck as SelectOptionObject).compareTo(typeaheadInputValue);
+                } else {
+                  return this.getDisplay(child.props.value.toString(), 'text').search(input) === 0;
+                }
+              })
             : childrenArray;
       }
     }
@@ -297,36 +408,40 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
     if (typeaheadFilteredChildren.length === 0) {
       !isCreatable &&
         typeaheadFilteredChildren.push(
-          <SelectOption isDisabled key={0} value={noResultsFoundText} isNoResultsOption />
+          <SelectOption isDisabled key="no-results" value={noResultsFoundText} isNoResultsOption />
         );
     }
-    if (isCreatable && e.target.value !== '') {
-      const newValue = e.target.value;
-      typeaheadFilteredChildren.push(
-        <SelectOption key={0} value={newValue} onClick={() => onCreateOption && onCreateOption(newValue)}>
-          {createText} "{newValue}"
-        </SelectOption>
-      );
+    if (isCreatable && typeaheadInputValue !== '') {
+      const newValue = typeaheadInputValue;
+      if (
+        !typeaheadFilteredChildren.find(
+          (i: React.ReactElement) => i.props.value.toLowerCase() === newValue.toLowerCase()
+        )
+      ) {
+        typeaheadFilteredChildren.push(
+          <SelectOption
+            key={`create ${newValue}`}
+            value={newValue}
+            onClick={() => onCreateOption && onCreateOption(newValue)}
+          >
+            {createText} "{newValue}"
+          </SelectOption>
+        );
+      }
     }
 
     this.setState({
-      typeaheadInputValue: e.target.value,
-      typeaheadCurrIndex: -1,
-      typeaheadFilteredChildren,
-      creatableValue: e.target.value
+      typeaheadFilteredChildren
     });
-    this.refCollection = [[]];
   };
 
-  onClick = (e: React.MouseEvent) => {
+  onClick = (_e: React.MouseEvent) => {
     if (!this.props.isOpen) {
-      this.props.onToggle(true);
+      this.onToggle(true);
     }
-    e.stopPropagation();
   };
 
-  clearSelection = (e: React.MouseEvent) => {
-    e.stopPropagation();
+  clearSelection = (_e: React.MouseEvent) => {
     this.setState({
       typeaheadInputValue: null,
       typeaheadFilteredChildren: React.Children.toArray(this.props.children),
@@ -439,15 +554,16 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
       ? (this.refCollection[nextIndex][0].firstElementChild as HTMLElement)
       : this.refCollection[nextIndex][0];
 
+    let typeaheadInputValue = '';
+    if (isCreatable && optionTextElm.innerText.includes(createText)) {
+      typeaheadInputValue = this.state.creatableValue;
+    } else if (optionTextElm) {
+      typeaheadInputValue = optionTextElm.innerText;
+    }
     this.setState(prevState => ({
       typeaheadCurrIndex: updateCurrentIndex ? nextIndex : prevState.typeaheadCurrIndex,
       typeaheadStoredIndex: nextIndex,
-      typeaheadInputValue:
-        isCreatable && optionTextElm.innerText.includes(createText)
-          ? this.state.creatableValue
-          : optionTextElm
-          ? optionTextElm.innerText
-          : ''
+      typeaheadInputValue
     }));
   };
 
@@ -472,8 +588,12 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
       } else if (position === 'tab') {
         if (onFavorite) {
           if (this.inputRef.current === document.activeElement) {
-            const indexForFocus =
-              typeaheadCurrIndex !== -1 ? typeaheadCurrIndex : typeaheadStoredIndex !== -1 ? typeaheadStoredIndex : 0;
+            let indexForFocus = 0;
+            if (typeaheadCurrIndex !== -1) {
+              indexForFocus = typeaheadCurrIndex;
+            } else if (typeaheadStoredIndex !== -1) {
+              indexForFocus = typeaheadStoredIndex;
+            }
 
             if (this.refCollection[indexForFocus] !== null && this.refCollection[indexForFocus][0] !== null) {
               this.refCollection[indexForFocus][0].focus();
@@ -490,9 +610,12 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
             this.setState({ tabbedIntoFavoritesMenu: false });
           }
         } else {
-          this.props.onToggle(false);
+          this.onToggle(false);
         }
       } else if (!tabbedIntoFavoritesMenu) {
+        if (this.refCollection[0][0] === null) {
+          return;
+        }
         let nextIndex;
         if (typeaheadCurrIndex === -1 && position === 'down') {
           nextIndex = 0;
@@ -570,6 +693,13 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
     return null;
   };
 
+  setVieMoreNextIndex = () => {
+    this.setState({ viewMoreNextIndex: this.refCollection.length - 1 });
+  };
+
+  isLastOptionBeforeFooter = (index: any) =>
+    this.props.footer && index === this.refCollection.length - 1 ? true : false;
+
   render() {
     const {
       children,
@@ -579,7 +709,6 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
       customContent,
       variant,
       direction,
-      onToggle,
       onSelect,
       onClear,
       toggleId,
@@ -587,6 +716,7 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
       isGrouped,
       isPlain,
       isDisabled,
+      validated,
       selections: selectionsProp,
       typeAheadAriaLabel,
       clearSelectionsAriaLabel,
@@ -594,6 +724,8 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
       removeSelectionAriaLabel,
       'aria-label': ariaLabel,
       'aria-labelledby': ariaLabelledBy,
+      'aria-describedby': ariaDescribedby,
+      'aria-invalid': ariaInvalid,
       placeholderText,
       width,
       maxHeight,
@@ -605,22 +737,29 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
       inlineFilterPlaceholderText,
       /* eslint-disable @typescript-eslint/no-unused-vars */
       onFilter,
+      /* eslint-disable @typescript-eslint/no-unused-vars */
+      onTypeaheadInputChanged,
       onCreateOption,
       isCreatable,
+      onToggle,
       createText,
       noResultsFoundText,
       customBadgeText,
       inputIdPrefix,
+      /* eslint-disable @typescript-eslint/no-unused-vars */
+      isInputValuePersisted,
       /* eslint-enable @typescript-eslint/no-unused-vars */
       menuAppendTo,
       favorites,
       onFavorite,
       /* eslint-disable @typescript-eslint/no-unused-vars */
       favoritesLabel,
+      footer,
+      loadingVariant,
       ...props
     } = this.props;
     const {
-      openedOnEnter,
+      focusFirstOption: openedOnEnter,
       typeaheadCurrIndex,
       typeaheadInputValue,
       typeaheadFilteredChildren,
@@ -636,12 +775,12 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
     let renderableItems: React.ReactNode[] = [];
     if (onFavorite) {
       // if variant is type-ahead call the extendTypeaheadChildren before adding favorites
-      const tempExtendedChildren =
-        variant === 'typeahead' || variant === 'typeaheadmulti'
-          ? this.extendTypeaheadChildren(typeaheadCurrIndex, favoritesGroup)
-          : onFavorite
-          ? favoritesGroup.concat(children)
-          : children;
+      let tempExtendedChildren: (React.ReactElement | React.ReactNode | {})[] = children;
+      if (variant === 'typeahead' || variant === 'typeaheadmulti') {
+        tempExtendedChildren = this.extendTypeaheadChildren(typeaheadCurrIndex, favoritesGroup);
+      } else if (onFavorite) {
+        tempExtendedChildren = favoritesGroup.concat(children);
+      }
       // mark items that are favorited with isFavorite
       renderableItems = extendItemsWithFavorite(tempExtendedChildren, isGrouped, favorites);
     } else {
@@ -659,6 +798,28 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
       }
     }
 
+    if (isOpen) {
+      if (renderableItems.find(item => (item as any)?.key === 'loading') === undefined) {
+        if (loadingVariant === 'spinner') {
+          renderableItems.push(
+            <SelectOption isLoading key="loading" value="loading">
+              <Spinner size="lg" />
+            </SelectOption>
+          );
+        } else if (loadingVariant?.text) {
+          renderableItems.push(
+            <SelectOption
+              isLoad
+              key="loading"
+              value={loadingVariant.text}
+              setViewMoreNextIndex={this.setVieMoreNextIndex}
+              onClick={loadingVariant?.onClick}
+            />
+          );
+        }
+      }
+    }
+
     const hasOnClear = onClear !== Select.defaultProps.onClear;
     const clearBtn = (
       <button
@@ -701,7 +862,6 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
       );
     }
 
-    let filterWithChildren = children;
     if (hasInlineFilter) {
       const filterBox = (
         <React.Fragment>
@@ -715,12 +875,26 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
               onKeyDown={event => {
                 if (event.key === KeyTypes.ArrowUp) {
                   this.handleMenuKeys(0, 0, 'up');
+                  event.preventDefault();
                 } else if (event.key === KeyTypes.ArrowDown) {
                   this.handleMenuKeys(0, 0, 'down');
+                  event.preventDefault();
                 } else if (event.key === KeyTypes.ArrowLeft) {
                   this.handleMenuKeys(0, 0, 'left');
+                  event.preventDefault();
                 } else if (event.key === KeyTypes.ArrowRight) {
                   this.handleMenuKeys(0, 0, 'right');
+                  event.preventDefault();
+                } else if (event.key === KeyTypes.Tab && variant === SelectVariant.checkbox) {
+                  // More modal-like experience for checkboxes
+                  // Let SelectOption handle this
+                  if (event.shiftKey) {
+                    this.handleMenuKeys(0, 0, 'up');
+                  } else {
+                    this.handleMenuKeys(0, 0, 'down');
+                  }
+                  event.stopPropagation();
+                  event.preventDefault();
                 }
               }}
               ref={this.filterRef}
@@ -730,8 +904,7 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
           <Divider key="inline-filter-divider" />
         </React.Fragment>
       );
-      this.refCollection[0][0] = this.filterRef.current;
-      filterWithChildren = [filterBox, ...(typeaheadFilteredChildren as React.ReactElement[])].map((option, index) =>
+      renderableItems = [filterBox, ...(typeaheadFilteredChildren as React.ReactElement[])].map((option, index) =>
         React.cloneElement(option, { key: index })
       );
     }
@@ -750,6 +923,7 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
         case 'single':
           variantProps = {
             selected: selections[0],
+            hasInlineFilter,
             openedOnEnter
           };
           variantChildren = renderableItems;
@@ -758,9 +932,10 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
           variantProps = {
             checked: selections,
             isGrouped,
-            hasInlineFilter
+            hasInlineFilter,
+            openedOnEnter
           };
-          variantChildren = filterWithChildren;
+          variantChildren = renderableItems;
           break;
         case 'typeahead':
           variantProps = {
@@ -785,7 +960,7 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
       }
     }
 
-    const menuContainer = (
+    const innerMenu = (
       <SelectMenu
         {...props}
         isGrouped={isGrouped}
@@ -798,20 +973,30 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
         keyHandler={this.handleMenuKeys}
         maxHeight={maxHeight}
         ref={this.menuComponentRef}
+        footer={footer}
+        footerRef={this.footerRef}
+        isLastOptionBeforeFooter={this.isLastOptionBeforeFooter}
       >
         {variantChildren}
       </SelectMenu>
     );
 
+    const menuContainer = footer ? <div className={css(styles.selectMenu)}> {innerMenu} </div> : innerMenu;
+
     const popperContainer = (
       <div
         className={css(
           styles.select,
           isOpen && styles.modifiers.expanded,
+          validated === ValidatedOptions.success && styles.modifiers.success,
+          validated === ValidatedOptions.warning && styles.modifiers.warning,
+          validated === ValidatedOptions.error && styles.modifiers.invalid,
           direction === SelectDirection.up && styles.modifiers.top,
           className
         )}
         {...(width && { style: { width } })}
+        {...(validated !== ValidatedOptions.default && { 'aria-describedby': ariaDescribedby })}
+        {...(validated !== ValidatedOptions.default && { 'aria-invalid': ariaInvalid })}
       >
         {isOpen && menuContainer}
       </div>
@@ -822,20 +1007,26 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
         className={css(
           styles.select,
           isOpen && styles.modifiers.expanded,
+          validated === ValidatedOptions.success && styles.modifiers.success,
+          validated === ValidatedOptions.warning && styles.modifiers.warning,
+          validated === ValidatedOptions.error && styles.modifiers.invalid,
           direction === SelectDirection.up && styles.modifiers.top,
           className
         )}
         ref={this.parentRef}
         {...getOUIAProps(Select.displayName, ouiaId !== undefined ? ouiaId : this.state.ouiaStateId, ouiaSafe)}
         {...(width && { style: { width } })}
+        {...(validated !== ValidatedOptions.default && { 'aria-describedby': ariaDescribedby })}
+        {...(validated !== ValidatedOptions.default && { 'aria-invalid': ariaInvalid })}
       >
         <SelectToggle
           id={selectToggleId}
           parentRef={this.parentRef}
           menuRef={this.menuComponentRef}
+          {...(footer && { footerRef: this.footerRef })}
           isOpen={isOpen}
           isPlain={isPlain}
-          onToggle={onToggle}
+          onToggle={this.onToggle}
           onEnter={this.onEnter}
           onClose={this.onClose}
           variant={variant}
@@ -844,6 +1035,7 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
           handleTypeaheadKeys={this.handleTypeaheadKeys}
           isDisabled={isDisabled}
           hasClearButton={hasOnClear}
+          hasFooter={footer !== undefined}
           onClickTypeaheadToggleButton={this.onClickTypeaheadToggleButton}
         >
           {customContent && (
@@ -915,6 +1107,7 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
                   aria-activedescendant={typeaheadActiveChild && typeaheadActiveChild.id}
                   id={`${selectToggleId}-select-multi-typeahead-typeahead`}
                   aria-label={typeAheadAriaLabel}
+                  aria-invalid={validated === ValidatedOptions.error}
                   placeholder={placeholderText as string}
                   value={typeaheadInputValue !== null ? typeaheadInputValue : ''}
                   type="text"
@@ -928,6 +1121,21 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
               {hasOnClear && ((selections && selections.length > 0) || typeaheadInputValue) && clearBtn}
             </React.Fragment>
           )}
+          {validated === ValidatedOptions.success && (
+            <span className={css(styles.selectToggleStatusIcon)}>
+              <CheckCircleIcon aria-hidden="true" />
+            </span>
+          )}
+          {validated === ValidatedOptions.error && (
+            <span className={css(styles.selectToggleStatusIcon)}>
+              <ExclamationCircleIcon aria-hidden="true" />
+            </span>
+          )}
+          {validated === ValidatedOptions.warning && (
+            <span className={css(styles.selectToggleStatusIcon)}>
+              <ExclamationTriangleIcon aria-hidden="true" />
+            </span>
+          )}
         </SelectToggle>
         {isOpen && menuAppendTo === 'inline' && menuContainer}
       </div>
