@@ -2,7 +2,7 @@ import * as React from 'react';
 import styles from '@patternfly/react-styles/css/components/Select/select';
 import buttonStyles from '@patternfly/react-styles/css/components/Button/button';
 import { css } from '@patternfly/react-styles';
-import CaretDownIcon from '@patternfly/react-icons/dist/js/icons/caret-down-icon';
+import CaretDownIcon from '@patternfly/react-icons/dist/esm/icons/caret-down-icon';
 import { KeyTypes, SelectVariant } from './selectConstants';
 import { PickOptional } from '../../helpers/typeUtils';
 
@@ -35,6 +35,8 @@ export interface SelectToggleProps extends React.HTMLProps<HTMLElement> {
   isPlain?: boolean;
   /** Flag indicating if select is disabled */
   isDisabled?: boolean;
+  /** Flag indicating if placeholder styles should be applied */
+  hasPlaceholderStyle?: boolean;
   /** Type of the toggle button, defaults to 'button' */
   type?: 'reset' | 'button' | 'submit' | undefined;
   /** Id of label for the Select aria-labelledby */
@@ -61,6 +63,7 @@ export class SelectToggle extends React.Component<SelectToggleProps> {
     isActive: false,
     isPlain: false,
     isDisabled: false,
+    hasPlaceholderStyle: false,
     hasClearButton: false,
     hasFooter: false,
     variant: 'single',
@@ -215,6 +218,7 @@ export class SelectToggle extends React.Component<SelectToggleProps> {
       isActive,
       isPlain,
       isDisabled,
+      hasPlaceholderStyle,
       variant,
       onToggle,
       onEnter,
@@ -256,11 +260,13 @@ export class SelectToggle extends React.Component<SelectToggleProps> {
             type={type}
             className={css(
               styles.selectToggle,
+              hasPlaceholderStyle && styles.modifiers.placeholder,
               isDisabled && styles.modifiers.disabled,
               isPlain && styles.modifiers.plain,
               isActive && styles.modifiers.active,
               className
             )}
+            aria-label={ariaLabel}
             // eslint-disable-next-line @typescript-eslint/no-unused-vars
             onClick={_event => {
               onToggle(!isOpen);
@@ -283,6 +289,7 @@ export class SelectToggle extends React.Component<SelectToggleProps> {
             ref={this.toggle as React.RefObject<HTMLDivElement>}
             className={css(
               styles.selectToggle,
+              hasPlaceholderStyle && styles.modifiers.placeholder,
               isDisabled && styles.modifiers.disabled,
               isPlain && styles.modifiers.plain,
               isTypeahead && styles.modifiers.typeahead,
