@@ -1,8 +1,8 @@
 import React from "react";
 import PropTypes from "prop-types";
-import Helpers from "../victory-util/helpers";
+import * as Helpers from "../victory-util/helpers";
 import { assign } from "lodash";
-import CommonProps from "../victory-util/common-props";
+import * as CommonProps from "../victory-util/common-props";
 import Line from "./line";
 
 const evaluateProps = (props) => {
